
**Eye Vision**
===========

[![Downloads](https://pepy.tech/badge/eye-vision)](https://pepy.tech/project/eye-vision)

Eye Vision provides a simple but powerful python library for Computer Vision. It uses
well know libraries like OpenCv and Matplotlib. Typical usage
often looks like this::

    import ziso
    from ziso import read
    from ziso import view
    
    # to read the image in the rgb color scale
    file = read.rgb("test.jpg")
    # to view the image
    view.im(file)
    
    # to view the easter egg in the library
    from ziso import zen

Speed
=========

Your favourite libraries compressed:

* OpenCV

* Matplotlib

* etc

Note:
-------------

Things to expect and know:

1. Easy implementation

2. Rapid Scalability

3. Portability

Read the Docs:-> Urls are https://eye-vision.readthedocs.io <br>
Eye-vision webpage:-> https://simbatmotsi.github.io/eye-vision/ <br>
Personal webpage:-> <http://bit.ly/simbatmotsi>